@@ -15,7 +15,6 @@ CLIENT_ID = '22e566527758690e6feb2b5cb300cc43'
 CLIENT_SECRET = '3a7815c3f9a82c3448ee4e7d3aa484a4'
 
 def main():
-
     parser = argparse.ArgumentParser(description='SoundScrape. Scrape an artist from SoundCloud.\n')
     parser.add_argument('artist_url', metavar='U', type=str,
                    help='An artist\'s SoundCloud username or URL')
@@ -55,14 +54,18 @@ def download_tracks(client, tracks, num_tracks=sys.maxint):
         # "Track" and "Resource" objects are actually different, 
         # even though they're the same. 
         if isinstance(track, soundcloud.resource.Resource):
-            t_track = {}
-            t_track['downloadable'] = track.downloadable
-            t_track['title'] = track.title
-            t_track['user'] = {'username': track.user['username']}
-            t_track['release_year'] = track.release
-            t_track['genre'] = track.genre
-            t_track['stream_url'] = track.stream_url
-            track = t_track
+            try:
+                t_track = {}
+                t_track['downloadable'] = track.downloadable
+                t_track['title'] = track.title
+                t_track['user'] = {'username': track.user['username']}
+                t_track['release_year'] = track.release
+                t_track['genre'] = track.genre
+                t_track['stream_url'] = track.stream_url
+                track = t_track
+            except Exception, e:
+                puts(track.title.encode('utf-8') + colored.red(u' is not downloadable') + '.')
+                continue
 
         if i > num_tracks - 1:
             continue
@@ -88,15 +91,10 @@ def download_file(url, path):
     r = requests.get(url, stream=True)
     with open(path, 'wb') as f:
         total_length = int(r.headers.get('content-length'))
-        dl = 0
         for chunk in progress.bar(r.iter_content(chunk_size=1024), expected_size=(total_length/1024) + 1): 
             if chunk: # filter out keep-alive new chunks
                 f.write(chunk)
                 f.flush()
-                
-                # done = int(50 * dl / total_length)
-                # sys.stdout.write("\r[%s%s]" % ('=' * done, ' ' * (50-done)) )    
-                # sys.stdout.flush()
 
     return path
 
